﻿Imports Infragistics.Win.UltraWinGanttView
Imports Infragistics.Win.UltraWinSchedule

Public Class Form1

    Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        ' Call the method that creates a DataSet 
        Dim ds As DataSet = Me.GetSampleData()

        Me.DataGridView1.DataSource = theDataSet
        Me.DataGridView1.DataMember = "Tasks"
        Me.DataGridView1.Columns("AllProperties").Visible = False

        '-- set GanttView data source
        Me.SetDataSource()
    End Sub

    Private Function GetSampleData() As DataSet
        'Dim theDataSet As New DataSet()
        Dim projectKey As String = "projectKey"

        Dim theProjects As DataTable = theDataSet.Tables.Add("Projects")
        theProjects.Columns.Add("ProjectID")
        theProjects.Columns.Add("ProjectKey")
        theProjects.Columns.Add("ProjectName")
        theProjects.Columns.Add("ProjectStartTime", GetType(DateTime))
        ' Assign values for each Project member 
        theProjects.Rows.Add(New [Object]() {Guid.NewGuid(), projectKey, "QuarterlyProject", DateTime.Today})

        Dim theTasks As DataTable = theDataSet.Tables.Add("Tasks")
        theTasks.Columns.Add("TaskID")
        theTasks.Columns.Add("ProjectKey")
        theTasks.Columns.Add("TaskName")
        theTasks.Columns.Add("TaskStartTime", GetType(DateTime))
        theTasks.Columns.Add("TaskDuration", GetType(TimeSpan))
        theTasks.Columns.Add("ParentTaskID")
        theTasks.Columns.Add("Constraint", GetType(Object))

        theTasks.Columns.Add("TaskPercentComplete")
        'The Task properties are all covered by individual members. But we could save space in the database
        'By storing data as binary using AllProperties and not binding the other fields.
        theTasks.Columns.Add("AllProperties", GetType(Byte()))


        ' Here is the new code
        Dim dr As New DataRelation("RR", theTasks.Columns("TaskID"), theTasks.Columns("ParentTaskID"), True)
        theDataSet.Relations.Add(dr)
        theDataSet.EnforceConstraints = True
        ' END 




        ' Parent Task1
        Dim planningTaskid As Guid = Guid.NewGuid()
        ' Assign values for each Task member 
        theTasks.Rows.Add(New [Object]() {planningTaskid, projectKey, "Planning", DateTime.Now, TimeSpan.FromDays(5), Nothing, TaskConstraint.StartNoEarlierThan, Nothing})
        ' Child Task1 of Parent Task1
        theTasks.Rows.Add(New [Object]() {Guid.NewGuid(), projectKey, "Prepare Budget", DateTime.Now, TimeSpan.FromDays(2), planningTaskid, TaskConstraint.StartNoEarlierThan, 100})
        ' Child Task2 of Parent Task1
        theTasks.Rows.Add(New [Object]() {Guid.NewGuid(), projectKey, "Allocate Teams", DateTime.Now.AddDays(2), TimeSpan.FromDays(3), planningTaskid, TaskConstraint.StartNoEarlierThan, Nothing})

        ' Parent Task2
        Dim implementationTaskid As Guid = Guid.NewGuid()
        theTasks.Rows.Add(New [Object]() {implementationTaskid, projectKey, "Implementation", DateTime.Now.AddDays(6), TimeSpan.FromDays(16), Nothing, TaskConstraint.StartNoEarlierThan, Nothing})
        Dim installationTaskid2 As Guid = Guid.NewGuid()


        ' Child Task1 of Parent Task2
        theTasks.Rows.Add(New [Object]() {installationTaskid2, projectKey, "Installations", DateTime.Now.AddDays(6), TimeSpan.FromDays(2), implementationTaskid, TaskConstraint.StartNoEarlierThan, 60})
        ' Child Task2 of Parent Task2
        theTasks.Rows.Add(New [Object]() {Guid.NewGuid(), projectKey, "Execution", DateTime.Now.AddDays(8), TimeSpan.FromDays(13), implementationTaskid, TaskConstraint.StartNoEarlierThan, Nothing})
        ' Parent Task3
        Dim testingTaskid As Guid = Guid.NewGuid()
        theTasks.Rows.Add(New [Object]() {testingTaskid, projectKey, "Testing", DateTime.Now.AddDays(23), TimeSpan.FromDays(20), Nothing, TaskConstraint.StartNoEarlierThan, Nothing})

        ' Child Task1 of Parent Task3
        theTasks.Rows.Add(New [Object]() {Guid.NewGuid(), projectKey, "TestPhase1", DateTime.Now.AddDays(23), TimeSpan.FromDays(10), testingTaskid, TaskConstraint.StartNoEarlierThan, 20})
        ' Child Task2 of Parent Task3
        theTasks.Rows.Add(New [Object]() {Guid.NewGuid(), projectKey, "TestPhase2", DateTime.Now.AddDays(36), TimeSpan.FromDays(9), testingTaskid, TaskConstraint.StartNoEarlierThan, Nothing})

        Return theDataSet
    End Function

    Private Sub RequeryButton_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles RequeryButton.Click
        '-- reset databindings to default
        Me.UltraCalendarInfo1.ResetDataBindingsForTasks()
        Me.UltraCalendarInfo1.ResetDataBindingsForProjects()

        ''-- re-set GanttView data source
        Me.SetDataSource()
    End Sub

    Private Sub SetDataSource()
        ' Set the BindingContextControl property to reference this form 
        Me.UltraCalendarInfo1.DataBindingsForTasks.BindingContextControl = Me
        Me.UltraCalendarInfo1.DataBindingsForProjects.BindingContextControl = Me

        ' Set the DataBinding members for Projects 
        Me.UltraCalendarInfo1.DataBindingsForProjects.SetDataBinding(theDataSet, "Projects")
        Me.UltraCalendarInfo1.DataBindingsForProjects.IdMember = "ProjectID"
        Me.UltraCalendarInfo1.DataBindingsForProjects.KeyMember = "ProjectKey"
        Me.UltraCalendarInfo1.DataBindingsForProjects.NameMember = "ProjectName"
        Me.UltraCalendarInfo1.DataBindingsForProjects.StartDateMember = "ProjectStartTime"

        ' Set the DataBinding members for Tasks
        Me.UltraCalendarInfo1.DataBindingsForTasks.SetDataBinding(theDataSet, "Tasks")

        ' Basic Task properties 
        Me.UltraCalendarInfo1.DataBindingsForTasks.NameMember = "TaskName"
        Me.UltraCalendarInfo1.DataBindingsForTasks.DurationMember = "TaskDuration"
        Me.UltraCalendarInfo1.DataBindingsForTasks.StartDateTimeMember = "TaskStartTime"
        Me.UltraCalendarInfo1.DataBindingsForTasks.IdMember = "TaskID"
        Me.UltraCalendarInfo1.DataBindingsForTasks.ProjectKeyMember = "ProjectKey"
        Me.UltraCalendarInfo1.DataBindingsForTasks.ParentTaskIdMember = "ParentTaskID"
        Me.UltraCalendarInfo1.DataBindingsForTasks.ConstraintMember = "Constraint"
        Me.UltraCalendarInfo1.DataBindingsForTasks.PercentCompleteMember = "TaskPercentComplete"
        'All other properties
        Me.UltraCalendarInfo1.DataBindingsForTasks.AllPropertiesMember = "AllProperties"

        ' Since we are showing a task that belongs to an explicitly defined 
        ' project (i.e., not the UnassignedProject), assign that project to 
        ' the control's Project property so the control knows to display that project. 
        Me.UltraGanttView1.CalendarInfo = Me.UltraCalendarInfo1
        Me.UltraGanttView1.Project = Me.UltraGanttView1.CalendarInfo.Projects(1)
    End Sub

End Class
